# リンクテスト

## デフォルト

- Module1
    - {ref}`module1.sampleprocedure`
    - {vb:function}`module1.sampleprocedure`
    - <project:#module1.sampleprocedure>
    - [sampleProcedure()](module1.sampleprocedure)
- モジュール1
    - {ref}`cd94f36.ec2a54`
    - {vb:function}`cd94f36.ec2a54`
    - <project:#cd94f36.ec2a54>
    - [名前呼び()](cd94f36.ec2a54)

## ラベルにファイル名を付ける

- Module1
    - {ref}`modules-module1.sampleprocedure`
    - {vb:function}`modules-module1.sampleprocedure`
    - <project:#modules-module1.sampleprocedure>
    - [sampleProcedure()](modules-module1.sampleprocedure)
- モジュール1
    - {ref}`modules-cd94f36.ec2a54`
    - {vb:function}`modules-cd94f36.ec2a54`
    - <project:#modules-cd94f36.ec2a54>
    - [名前呼び()](modules-cd94f36.ec2a54)

## ラベルのファイル名の区切り文字

- Module1
    - {ref}`modules__module1.sampleprocedure`
    - {vb:function}`modules__module1.sampleprocedure`
    - <project:#modules__module1.sampleprocedure>
    - [sampleProcedure()](modules__module1.sampleprocedure)
- モジュール1
    - {ref}`modules__cd94f36.ec2a54`
    - {vb:function}`modules__cd94f36.ec2a54`
    - <project:#modules__cd94f36.ec2a54>
    - [名前呼び()](modules__cd94f36.ec2a54)

## Autodoc でモジュールのラベルを生成する

- Module1
    - {ref}`module1`
    - {vb:function}`module1`
    - <project:#module1>
    - [Module1](module1)
- モジュール1
    - {ref}`cd94f36`
    - {vb:function}`cd94f36`
    - <project:#cd94f36>
    - [モジュール1](cd94f36)

### ラベルにファイル名を付ける

- Module1
    - {ref}`modules-module1`
    - {vb:function}`modules-module1`
    - <project:#modules-module1>
    - [Module1](modules-module1)
- モジュール1
    - {ref}`modules-cd94f36`
    - {vb:function}`modules-cd94f36`
    - <project:#modules-cd94f36>
    - [モジュール1](modules-cd94f36)
